@@ -11,7 +11,7 @@ class ModelInterface:
     def download_model(self, model_name):
         # TODO: we can introduce versioning to S3 here
         temp_model_path = 'tmp_model'
-        s3_client.download_file(self.bucket_name, model_name, temp_model_path)
+        self.s3_client.download_file(self.bucket_name, model_name, temp_model_path)
         predictions, algo = dump.load(file_name=temp_model_path)
         os.remove(temp_model_path)
         return Model(algo)
@@ -19,5 +19,5 @@ class ModelInterface:
     def save_model(self, model_name, model):
         temp_model_path = 'tmp_model'
         dump.dump(file_name=temp_model_path, predictions=None, algo=model)
-        s3_client.upload_file(temp_model_path, self.bucket_name, model_name)
+        self.s3_client.upload_file(temp_model_path, self.bucket_name, model_name)
         os.remove(temp_model_path)
\ No newline at end of file
