@@ -1,7 +1,7 @@
 import os
 from sqlalchemy import create_engine, Column, Text, SmallInteger, Integer, TIMESTAMP
 from sqlalchemy.ext.declarative import declarative_base
-from sqlalchemy.orm import sessionmaker
+from sqlalchemy.orm import sessionmaker, scoped_session
 
 class Database:
     def __init__(self, user, password, host, port, database, **kwargs):
@@ -13,7 +13,7 @@ class Database:
     def load_session(self):
         # TODO: should we checkout scoped sessions
         Session = sessionmaker(bind=self.engine)
-        return Session()
+        return scoped_session(Session())
 class RDSDatabase(Database):
     def __init__(self, user, password, host, port, database, **kwargs):
         super().__init__(user, password, host, port, database, **kwargs)
